@@ -7,77 +7,35 @@ from copy import deepcopy
 import numpy as np
 from astropy.units.quantity import Quantity
 
-from .abstract_list import __dimensions_list__  # lgtm [py/import-own-module]
-from .abstract_list import DependentVariableList  # lgtm [py/import-own-module]
-from .abstract_list import DimensionList  # lgtm [py/import-own-module]
+from .abstract_list import __dimensions_list__
+from .abstract_list import DependentVariableList
+from .abstract_list import DimensionList
 from .dependent_variable import as_dependent_variable  # noqa: F401
-from .dependent_variable import DependentVariable  # lgtm [py/import-own-module]
-from .dimension import as_dimension  # lgtm [py/import-own-module]
-from .dimension import Dimension  # lgtm [py/import-own-module] # noqa: F401
-from .dimension import LabeledDimension  # lgtm [py/import-own-module] # noqa: F401
-from .dimension import LinearDimension  # lgtm [py/import-own-module] # noqa: F401
-from .dimension import MonotonicDimension  # lgtm [py/import-own-module] # noqa: F401
-from .helper_functions import _preview  # lgtm [py/import-own-module]
+from .dependent_variable import DependentVariable
+from .dimension import as_dimension
+from .dimension import Dimension  # noqa: F401
+from .dimension import LabeledDimension  # noqa: F401
+from .dimension import LinearDimension  # noqa: F401
+from .dimension import MonotonicDimension  # noqa: F401
+from .helper_functions import _preview
+from .numpy_wrapper import __array_manipulation__
+from .numpy_wrapper import __function_reduction_list__
+from .numpy_wrapper import __other_functions__
+from .numpy_wrapper import __shape_manipulation_functions__
+from .numpy_wrapper import __ufunc_list_applies_to_unit__
+from .numpy_wrapper import __ufunc_list_dimensionless_unit__
+from .numpy_wrapper import __ufunc_list_unit_independent__
 from .numpy_wrapper import fft
-from .units import string_to_quantity  # lgtm [py/import-own-module]
-from .utils import _check_dimension_indices  # lgtm [py/import-own-module]
-from .utils import _get_broadcast_shape  # lgtm [py/import-own-module]
-from .utils import check_scalar_object  # lgtm [py/import-own-module]
-from .utils import validate  # lgtm [py/import-own-module]
+from .units import string_to_quantity
+from .utils import _check_dimension_indices
+from .utils import _get_broadcast_shape
+from .utils import check_scalar_object
+from .utils import get_CSDM_object__args__axes
+from .utils import np_check_for_out
+from .utils import np_check_pads
+from .utils import validate
 
 __all__ = ["CSDM"]
-__ufunc_list_dimensionless_unit__ = [
-    np.sin,
-    np.cos,
-    np.tan,
-    np.arcsin,
-    np.arccos,
-    np.arctan,
-    np.sinh,
-    np.cosh,
-    np.tanh,
-    np.arcsinh,
-    np.arccosh,
-    np.arctanh,
-    np.exp,
-    np.exp2,
-    np.log,
-    np.log2,
-    np.log10,
-    np.expm1,
-    np.log1p,
-]
-
-__ufunc_list_unit_independent__ = [
-    np.negative,
-    np.positive,
-    np.absolute,
-    np.fabs,
-    np.rint,
-    np.sign,
-    np.conj,
-    np.conjugate,
-]
-
-__ufunc_list_applies_to_unit__ = [np.sqrt, np.square, np.cbrt, np.reciprocal, np.power]
-
-__function_reduction_list__ = [
-    np.max,
-    np.min,
-    np.sum,
-    np.mean,
-    np.var,
-    np.std,
-    np.prod,
-    np.cumsum,
-    np.cumprod,
-    np.argmin,
-    np.argmax,
-]
-
-__other_functions__ = [np.round, np.real, np.imag, np.clip, np.around, np.angle]
-
-__shape_manipulation_functions__ = [np.transpose]
 
 
 class CSDM:
@@ -138,22 +96,22 @@ class CSDM:
         self._dimensions = DimensionList([])
         if "dimensions" in kwargs_keys:
             if not isinstance(kwargs["dimensions"], (list, DimensionList)):
-                t_ = type(kwargs["dimensions"])
+                dim_type = type(kwargs["dimensions"])
                 raise ValueError(
                     "A list of valid Dimension or equivalent dictionary objects is "
-                    f"required, found {t_}."
+                    f"required, found {dim_type}."
                 )
             _ = [self.dimensions.append(item) for item in kwargs["dimensions"]]
 
         self._dependent_variables = DependentVariableList([])
         if "dependent_variables" in kwargs_keys:
-            t_ = type(kwargs["dependent_variables"])
+            dv_type = type(kwargs["dependent_variables"])
             if not isinstance(
                 kwargs["dependent_variables"], (list, DependentVariableList)
             ):
                 raise ValueError(
                     "A list of valid DependentVariable or equivalent dictionary "
-                    f"objects is required, found {t_}."
+                    f"objects is required, found {dv_type}."
                 )
             for item in kwargs["dependent_variables"]:
                 if isinstance(item, dict):
@@ -297,7 +255,6 @@ class CSDM:
     #     raise NotImplementedError()
 
     def __ifunction__(self, function, symbol, other):
-
         if isinstance(other, CSDM):
             self.__check_csdm_object_additive_compatibility(other)
 
@@ -318,7 +275,7 @@ class CSDM:
                 f_n(factor * other.value)
         return self
 
-    def _default_addition_(self, other, fn, operation):
+    def _default_addition_(self, other, f_n, operation):
         """Operate on two objects (z=x+/-y), if the other object is a
             1) csdm or scalar object,
             2) with identical dimension objects,
@@ -327,35 +284,35 @@ class CSDM:
 
         Args:
             other: the object to add/subtract
-            fn: addition/subtraction function
+            f_n: addition/subtraction function
             operation: "+" or "-"
         """
         if isinstance(other, CSDM):
             self.__check_csdm_object_additive_compatibility(other)
 
-            d1 = self.copy()
-            for i, item in enumerate(d1.dependent_variables):
+            obj = self.copy()
+            for i, item in enumerate(obj.dependent_variables):
                 factor = other.dependent_variables[i].unit.to(item.unit)
-                item.components = item.components + fn(
+                item.components = item.components + f_n(
                     factor, other.dependent_variables[i].components
                 )
-            return d1
+            return obj
 
         other = check_scalar_object(other, operation)
-        d1 = self.copy()
-        for i, item in enumerate(d1.dependent_variables):
+        obj = self.copy()
+        for i, item in enumerate(obj.dependent_variables):
             item.components = (
-                item.components + fn(1, other)
+                item.components + f_n(1, other)
                 if not isinstance(other, Quantity)
-                else item.components + fn(1, other.unit.to(item.unit) * other.value)
+                else item.components + f_n(1, other.unit.to(item.unit) * other.value)
             )
-        return d1
+        return obj
 
     def __add__(self, other):
         """Add two objects (z=x+y)"""
 
-        def function(a, b):
-            return a * b
+        def function(val_1, val_2):
+            return val_1 * val_2
 
         return self._default_addition_(other, function, "+")
 
@@ -370,8 +327,8 @@ class CSDM:
     def __sub__(self, other):
         """Subtract two objects (z=x+y)"""
 
-        def function(a, b):
-            return -a * b
+        def function(val_1, val_2):
+            return -val_1 * val_2
 
         return self._default_addition_(other, function, "-")
 
@@ -387,15 +344,15 @@ class CSDM:
         """Multiply the components of the CSDM object by a scalar."""
         other = check_scalar_object(other, "*")
 
-        d1 = self.copy()
-        for item in d1.dependent_variables:
+        obj = self.copy()
+        for item in obj.dependent_variables:
             if not isinstance(other, Quantity):
                 item.components = item.components * other
             else:
                 value = 1 * item.subtype._unit * other
                 item.subtype._unit = value.unit
                 item.components = item.components * value.value
-        return d1
+        return obj
 
     def __rmul__(self, other):
         """Right multiply the components of the CSDM object by a scalar."""
@@ -419,15 +376,15 @@ class CSDM:
         """Divide the components of the CSDM object by a scalar."""
         other = check_scalar_object(other, "/")
 
-        d1 = self.copy()
-        for item in d1.dependent_variables:
+        obj = self.copy()
+        for item in obj.dependent_variables:
             if not isinstance(other, Quantity):
                 item.components = item.components / other
             else:
                 value = (1 * item.subtype._unit) / other
                 item.subtype._unit = value.unit
                 item.components = item.components * value.value
-        return d1
+        return obj
 
     def __rtruediv__(self, other):
         """Right divide the components of the CSDM object by a scalar."""
@@ -461,9 +418,9 @@ class CSDM:
 
     def _get_indices(self, indices):
         if isinstance(indices, tuple):
-            l_ = len(indices)
+            size = len(indices)
             indices = indices + tuple(
-                slice(0, _.count, 1) for _ in self.dimensions[l_:]
+                slice(0, _.count, 1) for _ in self.dimensions[size:]
             )
         if isinstance(indices, (int, slice)):
             indices = (indices,) + tuple(
@@ -490,42 +447,30 @@ class CSDM:
         indices = self._get_indices(indices)
         csdm = CSDM()
         for i, dim in enumerate(self.dimensions):
-            s_ = indices[i]
-
-            dim_ = dim.subtype if hasattr(dim, "subtype") else dim
-
-            length_ = dim.coordinates[s_].size
-            if length_ > 1:
-                if hasattr(dim_, "_equivalencies"):
-                    equivalencies_ = dim_._equivalencies
-                    dim_._equivalencies = None
-                    x = dim.coordinates[s_]
-                    new_dim = as_dimension(x.value, unit=str(x.unit))
-                    dim_._equivalencies = equivalencies_
-                    new_dim._equivalencies = equivalencies_
-
-                else:
-                    x = dim.coordinates[s_]
-                    new_dim = as_dimension(x)
-
-                new_dim._copy_metadata(dim_)
-                if hasattr(new_dim, "complex_fft"):
-                    new_dim.complex_fft = False
-
+            dim_ = Dimension(**dim.dict()) if not hasattr(self, "subtype") else dim
+            dim_.copy_metadata(dim)
+            new_dim = dim_[indices[i]]
+            if new_dim.size > 1:
                 csdm._dimensions += [new_dim]
 
         for variable in self.dependent_variables:
             section = (slice(0, len(variable.components), 1),) + indices[::-1]
-            y = variable.components[section]
-            dv = empty_dependent_variable(variable.numeric_type, variable.quantity_type)
-            dv.subtype._components = y
-            dv._copy_metadata(variable)
-            csdm._dependent_variables += [dv]
+            components = variable.components[section]
+            dv_obj = empty_dependent_variable(
+                variable.numeric_type, variable.quantity_type
+            )
+            dv_obj.subtype._components = components
+            dv_obj.copy_metadata(variable)
+            csdm._dependent_variables += [dv_obj]
 
-        csdm._copy_metadata(self)
+        csdm.copy_metadata(self)
+        if len(csdm.dimensions) == 0 and len(csdm.dependent_variables) == 1:
+            value = np.squeeze(csdm.dependent_variables[0].components)
+            unit = csdm.dependent_variables[0].unit
+            return value * unit
         return csdm
 
-    def _copy_metadata(self, other):
+    def copy_metadata(self, other):
         self._version = other._version
         self._description = other._description
         self._read_only = other._read_only
@@ -723,14 +668,14 @@ class CSDM:
     def T(self):
         """Return a csdm object with a transpose of the dataset."""
         new = CSDM()
-        new._copy_metadata(self)
+        new.copy_metadata(self)
         new._dimensions += self._dimensions[::-1]
 
         for item in self.dependent_variables:
-            dv = empty_dependent_variable(item.numeric_type, item.quantity_type)
-            dv._copy_metadata(item)
-            dv.subtype._components = np.moveaxis(item.subtype._components.T, -1, 0)
-            new._dependent_variables += [dv]
+            dv_obj = empty_dependent_variable(item.numeric_type, item.quantity_type)
+            dv_obj.copy_metadata(item)
+            dv_obj.subtype._components = np.moveaxis(item.subtype._components.T, -1, 0)
+            new._dependent_variables += [dv_obj]
 
         return new
 
@@ -749,6 +694,34 @@ class CSDM:
         """Return the total number of dimensions."""
         return len(self.dimensions)
 
+    def reshape(self, shape):
+        """Reshape the csdm object to shape.
+
+        Args:
+            shape: A list of dimension objects or integers.
+        """
+        size = self.y[0].components[0].size
+
+        shape_int = [item if isinstance(item, int) else item.size for item in shape]
+        new_dim = []
+        for index in shape:
+            sh = int(-size / np.prod(shape_int)) if index == -1 else index
+            dim = (
+                Dimension(type="linear", count=sh, increment="1")
+                if isinstance(sh, int)
+                else sh
+            )
+            new_dim.append(dim)
+
+        for d_v in self.y:
+            new_shape = (d_v.components.shape[0],) + tuple(shape_int[::-1])
+            new_dv = as_dependent_variable(array=d_v.components.reshape(new_shape))
+            new_dv.copy_metadata(d_v)
+
+        new_csdm = CSDM(dimensions=new_dim, dependent_variables=[new_dv])
+        new_csdm.copy_metadata(self)
+        return new_csdm
+
     # ----------------------------------------------------------------------- #
     #                                  Methods                                #
     # ----------------------------------------------------------------------- #
@@ -1102,8 +1075,8 @@ class CSDM:
         return self.T
 
     def fft(self, axis=0):
-        """Perform a FFT along the given `dimension=axis`, for linear dimension, assuming
-        Nyquist-Shannon relation.
+        """Perform a FFT along the given `dimension=axis`, for linear dimension,
+        assuming Nyquist-Shannon relation.
 
         Args:
             axis: dimension index along which the FFT is performed.
@@ -1118,7 +1091,7 @@ class CSDM:
         .. code:: python
 
             phase = np.exp(-2j * np.pi * coordinates_offset * reciprocal_coordinates)
-            x_fft = np.fft.fftshift(np.fft.fft(x)) * phase
+            x_fft = sp.fft.fftshift(sp.fft.fft(x)) * phase
 
         over all components for every dependent variable.
 
@@ -1127,7 +1100,7 @@ class CSDM:
         .. code:: python
 
             phase = np.exp(2j * np.pi * reciprocal_coordinates_offset * coordinates)
-            x = np.fft.ifft(np.fft.ifftshift(x_fft * phase))
+            x = sp.fft.ifft(sp.fft.ifftshift(x_fft * phase))
 
         over all components for every dependent variable.
 
@@ -1322,6 +1295,11 @@ class CSDM:
         return np.cumprod(self, axis=axis)
 
     def __array_ufunc__(self, function, method, *inputs, **kwargs):
+        if function == np.multiply:
+            return inputs[1] * inputs[0]
+        if function == np.divide:
+            return (1.0 / inputs[1]) * inputs[0]
+
         csdm = inputs[0]
         input_ = []
         if len(inputs) > 1:
@@ -1336,18 +1314,18 @@ class CSDM:
                         f"type `{variable.unit.physical_type}`."
                     )
                 factor[i] = variable.unit.to("")
-            return _get_new_csdm_object_after_applying_ufunc(
-                inputs[0], function, method, factor, *input_, **kwargs
+            return get_new_csdm_object_after_applying_ufunc(
+                csdm, function, method, factor, *input_, **kwargs
             )
 
         if function in __ufunc_list_unit_independent__:
-            return _get_new_csdm_object_after_applying_ufunc(
-                inputs[0], function, method, None, *input_, **kwargs
+            return get_new_csdm_object_after_applying_ufunc(
+                csdm, function, method, None, *input_, **kwargs
             )
 
         if function in __ufunc_list_applies_to_unit__:
-            obj = _get_new_csdm_object_after_applying_ufunc(
-                inputs[0], function, method, None, *input_, **kwargs
+            obj = get_new_csdm_object_after_applying_ufunc(
+                csdm, function, method, None, *input_, **kwargs
             )
             for i, variable in enumerate(obj.dependent_variables):
                 scalar = function(1 * variable.unit, *input_)
@@ -1359,27 +1337,54 @@ class CSDM:
 
     def __array_function__(self, function, _, *args, **kwargs):
         if function in __function_reduction_list__:
-            return _get_new_csdm_object_after_dimension_reduction_func(
+            return get_new_csdm_object_after_dimension_reduction_func(
                 function, *args[0], **args[1], **kwargs
             )
         if function in __other_functions__:
-            return _get_new_csdm_object_after_applying_function(
+            return get_new_csdm_object_after_applying_function(
                 function, *args[0], **args[1], **kwargs
             )
-        if function in __shape_manipulation_functions__:
-            if "axes" in args[1].keys():
-                args[1]["axes"] = (0,) + tuple(np.asarray(args[1]["axes"]) + 1)
-            else:
-                dim_len = len(args[0][0].dimensions)
-                args[1]["axes"] = (0,) + tuple(-i - 1 for i in range(dim_len))
+        if function in __array_manipulation__:
+            csdm = args[0][0]
+            args_ = ()
+            if len(args[0]) > 1:
+                args_ = args[0][1:]
+            args_kw = args[1]
+            return get_new_csdm_object_after_applying_ufunc(
+                csdm, function, None, None, *args_, **args_kw
+            )
+        if function in [np.pad]:
+            return apply_np_padding(function, *args, **kwargs)
 
-            csdm = _get_new_csdm_object_after_applying_function(
+        if function in [np.tile]:
+            return apply_np_tile(function, *args, **kwargs)
+
+        if function in __shape_manipulation_functions__:
+            dim_len = len(args[0][0].dimensions)
+            if "axes" in args[1].keys():
+                axes = (0,) + tuple(-np.asarray(args[1]["axes"]) - 1)
+                axes_dim = args[1]["axes"]
+                args[1]["axes"] = axes
+
+            elif len(args[0]) == 2:
+                args = list(args)
+                args[0] = list(args[0])
+                axes = (0,) + tuple(-np.asarray(args[0][1]) - 1)
+                axes_dim = args[0][1]
+                args[0][1] = axes
+            else:
+                axes = (0,) + tuple(-i - 1 for i in range(dim_len))
+                axes_dim = np.arange(dim_len)[::-1]
+                args[1]["axes"] = axes
+
+            csdm = get_new_csdm_object_after_applying_function(
                 function, *args[0], **args[1], **kwargs
             )
+
             csdm._dimensions = tuple(
-                csdm.dimensions[args[1]["axes"][1:][i]]
-                for i in range(len(csdm.dimensions))
+                csdm.dimensions[axes_dim[i]] for i in range(len(csdm.dimensions))
             )
+            return csdm
 
         # if function in __return_np__:
         #     if len(self.y) > 1:
@@ -1387,7 +1392,7 @@ class CSDM:
         #             f"Function {function.__name__} is not implemented for multi "
         #              "dependent variable csdm object."
         #         )
-        #     csdm, args_, axis, kwargs = _get_CSDM_object__args__axes(
+        #     csdm, args_, axis, kwargs = get_CSDM_object__args__axes(
         #         *args[0], **args[1], **kwargs
         #     )
         #     nd_array = csdm.y[0].components
@@ -1433,18 +1438,49 @@ class CSDM:
         """
         return _preview(self, reverse_axis, range, **kwargs)
 
+    def to_positive_inc(self):
+        """Convert the csdm object with negative increment dimensions to positive
+        increments.
 
-def _check_for_out(csdm, **kwargs):
-    out = kwargs.get("out", None)
-    if out is not None:
-        if len(csdm.dependent_variables) > 1:
-            raise NotImplementedError(
-                "Keyword `out` is not implemented for csdm objects with more that "
-                "one dependent variables."
+        Args:
+            csdm_obj: CSDM object
+        """
+        reverse_index = []
+        new_dimensions = []
+        for i, dim in enumerate(self.dimensions):
+            if dim.type in ["linear", "monotonic"]:
+                diff = dim.coordinates[1] - dim.coordinates[0]
+                if diff.value < 0:
+                    reverse_index.append(-i - 1)
+                    coords = dim.coordinates
+                    array, unit = coords.value[::-1], coords.unit
+                    new_axis = as_dimension(array=array, unit=str(unit))
+                    new_axis.copy_metadata(dim)
+                    new_dimensions.append(new_axis)
+                else:
+                    new_dimensions.append(dim)
+            else:
+                new_dimensions.append(dim)
+
+        new_dvs = []
+        for d_v in self.dependent_variables:
+            datum = d_v.components
+            datum = (
+                datum
+                if reverse_index == []
+                else np.flip(datum, axis=tuple(reverse_index))
             )
+            new_dv = as_dependent_variable(array=datum)
+            new_dv.copy_metadata(d_v)
+            new_dvs.append(new_dv)
+
+        new_csdm = CSDM(dimensions=new_dimensions, dependent_variables=new_dvs)
+        new_csdm.copy_metadata(self)
+
+        return new_csdm
 
 
-def _get_new_csdm_object_after_applying_ufunc(
+def get_new_csdm_object_after_applying_ufunc(
     csdm, func, method=None, factor=None, *inputs, **kwargs
 ):
     """Perform the operation, func, on the components of the dependent variables, and
@@ -1456,7 +1492,7 @@ def _get_new_csdm_object_after_applying_ufunc(
     if axis is not None:
         kwargs["axis"] = _check_dimension_indices(len(csdm.dimensions), axis)
 
-    _check_for_out(csdm, **kwargs)
+    np_check_for_out(csdm, **kwargs)
 
     new = CSDM()
 
@@ -1470,18 +1506,18 @@ def _get_new_csdm_object_after_applying_ufunc(
         obj = empty_dependent_variable(
             numeric_type=res.dtype, quantity_type=variable.quantity_type
         )
-        obj._copy_metadata(variable)
+        obj.copy_metadata(variable)
         obj.subtype._components = res
         new._dependent_variables += [obj]
         # obj = as_dependent_variable(y, quantity_type=variable.quantity_type)
-        # obj._copy_metadata(variable)
+        # obj.copy_metadata(variable)
         # new.add_dependent_variable(obj)
 
-    new._copy_metadata(csdm)
+    new.copy_metadata(csdm)
     return new
 
 
-def _get_new_csdm_object_after_applying_function(func, *args, **kwargs):
+def get_new_csdm_object_after_applying_function(func, *args, **kwargs):
     """Perform the operation, func, on the components of the dependent variables, and
     return the corresponding CSDM object.
     """
@@ -1490,7 +1526,7 @@ def _get_new_csdm_object_after_applying_function(func, *args, **kwargs):
     if len(args) > 1:
         args_ = args[1:]
 
-    _check_for_out(csdm, **kwargs)
+    np_check_for_out(csdm, **kwargs)
 
     new = CSDM()
 
@@ -1499,19 +1535,19 @@ def _get_new_csdm_object_after_applying_function(func, *args, **kwargs):
     new._dimensions = deepcopy(csdm.dimensions)
 
     for variable in csdm.dependent_variables:
-        y = func(variable.components, *args_, **kwargs)
+        components = func(variable.components, *args_, **kwargs)
         obj = empty_dependent_variable(
-            numeric_type=y.dtype, quantity_type=variable.quantity_type
+            numeric_type=components.dtype, quantity_type=variable.quantity_type
         )
-        obj._copy_metadata(variable)
-        obj.subtype._components = y
+        obj.copy_metadata(variable)
+        obj.subtype._components = components
         new._dependent_variables += [obj]
 
-    new._copy_metadata(csdm)
+    new.copy_metadata(csdm)
     return new
 
 
-def _get_new_csdm_object_after_apodization(csdm, func, arg, index=-1):
+def get_new_csdm_object_after_apodization(csdm, func, arg, index=-1):
     """Perform the operation, func, on the components of the dependent variables, and
     return the corresponding CSDM object.
     """
@@ -1545,50 +1581,28 @@ def _get_new_csdm_object_after_apodization(csdm, func, arg, index=-1):
     new._dimensions = deepcopy(csdm.dimensions)
 
     for variable in csdm.dependent_variables:
-        y = variable.components * apodization_vector_nd
+        components = variable.components * apodization_vector_nd
 
         obj = empty_dependent_variable(
-            numeric_type=y.dtype, quantity_type=variable.quantity_type
+            numeric_type=components.dtype, quantity_type=variable.quantity_type
         )
-        obj._copy_metadata(variable)
-        obj.subtype._components = y
+        obj.copy_metadata(variable)
+        obj.subtype._components = components
         new._dependent_variables += [obj]
 
         # obj = as_dependent_variable(y, quantity_type=variable.quantity_type)
-        # obj._copy_metadata(variable)
+        # obj.copy_metadata(variable)
         # new.add_dependent_variable(obj)
 
-    new._copy_metadata(csdm)
+    new.copy_metadata(csdm)
     return new
 
 
-def _get_CSDM_object__args__axes(*args, **kwargs):
-    # print(args)
-    axis = None
-    args_ = []
-    if args != ():
-        csdm = args[0]
-        args_ = list(args[1:])
-        if len(args) > 1:
-            args_[0] = _check_dimension_indices(len(csdm.dimensions), args[1])
-            axis = args_[0]
-    if "a" in kwargs.keys():
-        csdm = kwargs["a"]
-        kwargs.pop("a")
-    if "axis" in kwargs.keys():
-        if kwargs["axis"] is not None:
-            axis = _check_dimension_indices(len(csdm.dimensions), kwargs["axis"])
-            kwargs["axis"] = axis
-
-    _check_for_out(csdm, **kwargs)
-    return csdm, args_, axis, kwargs
-
-
-def _get_new_csdm_object_after_dimension_reduction_func(func, *args, **kwargs):
+def get_new_csdm_object_after_dimension_reduction_func(func, *args, **kwargs):
     """Perform the operation, func, on the components of the dependent variables, and
     return the corresponding CSDM object.
     """
-    csdm, args_, axis, kwargs = _get_CSDM_object__args__axes(*args, **kwargs)
+    csdm, args_, axis, kwargs = get_CSDM_object__args__axes(*args, **kwargs)
 
     new = CSDM()
     lst = []
@@ -1602,36 +1616,138 @@ def _get_new_csdm_object_after_dimension_reduction_func(func, *args, **kwargs):
                 new.dimensions.append(variable.copy())
 
     for variable in csdm.dependent_variables:
-        y = func(variable.components, *args_, **kwargs)
+        components = func(variable.components, *args_, **kwargs)
 
         if axis is not None:
             obj = empty_dependent_variable(
-                numeric_type=y.dtype, quantity_type=variable.quantity_type
+                numeric_type=components.dtype, quantity_type=variable.quantity_type
             )
-            obj._copy_metadata(variable)
-            obj.subtype._components = y
+            obj.copy_metadata(variable)
+            obj.subtype._components = components
             new._dependent_variables += [obj]
 
             # obj = as_dependent_variable(y, quantity_type=variable.quantity_type)
-            # obj._copy_metadata(variable)
+            # obj.copy_metadata(variable)
             # new.add_dependent_variable(obj)
         else:
-            lst.append(y * variable.unit)
+            lst.append(components * variable.unit)
 
     if axis is None:
         del new
-        # if len(lst) > 1:
-        #     return lst
         return lst if len(lst) > 1 else lst[0]
 
-    new._copy_metadata(csdm)
+    new.copy_metadata(csdm)
     return new
 
 
 def empty_dependent_variable(numeric_type, quantity_type="scalar"):
+    """Create an empty dependent variable object"""
     return DependentVariable(
         type="internal",
         components=np.empty(0),
         quantity_type=quantity_type,
         numeric_type=numeric_type,
     )
+
+
+def apply_np_padding(function, *args, **kwargs):
+    """Apply numpy padding"""
+    args0 = list(args[0])
+    n_dims = len(args0[0].x)
+    if "pad_width" in args[1].keys():
+        pads = np_check_pads(args[1]["pad_width"], n_dims)
+        pads = ((0, 0),) + tuple(pads)[::-1]
+        args[1]["pad_width"] = pads
+    else:
+        pads = np_check_pads(args0[1], n_dims)
+        pads = ((0, 0),) + tuple(pads)[::-1]
+        args0[1] = pads
+
+    for key, val in args[1].items():
+        if key in ["stat_length", "constant_values", "end_values"]:
+            args[1][key] = ((0, 0),) + tuple(np_check_pads(val, n_dims))[::-1]
+
+    csdm = get_new_csdm_object_after_applying_function(
+        function, *args0, **args[1], **kwargs
+    )
+    for dim, pads in zip(csdm.dimensions, pads[::-1][:-1]):
+        if dim.type == "linear":
+            dim.count += int(np.sum(pads))
+            offset = int(pads[0] / 2 - 1) if dim.complex_fft else pads[0]
+            dim.coordinates_offset -= dim.increment * offset
+        if dim.type == "monotonic":
+            inc = dim.coordinates[1] - dim.coordinates[0]
+            left = inc * (np.arange(pads[0]) - pads[0]) + dim.coordinates[0]
+            right = inc * np.arange(pads[1]) + dim.coordinates[0]
+            coords = np.concatenate((left, dim.coordinates, right))
+            dim.coordinates = coords
+        if dim.type == "labeled":
+            left = ["0"] * pads[0]
+            right = ["0"] * pads[1]
+            coords = left + list(dim.labels) + right
+            dim.labels = coords
+    return csdm
+
+
+def apply_np_tile(function, *args, **kwargs):
+    """Apply numpy tile"""
+    args0 = list(args[0])
+    use_arg_1 = "reps" in args[1].keys()
+    if use_arg_1:
+        reps = list(args[1]["reps"])
+    else:
+        reps = list(args0[1])
+
+    reps_int = np.array(
+        [
+            item.coordinates.size if isinstance(item, __dimensions_list__) else item
+            for item in reps
+        ],
+        dtype=int,
+    )
+
+    rep_size = reps_int.size
+    ori_size = len(args0[0].x)
+    ori_count = [
+        item.coordinates.size if isinstance(reps[i], __dimensions_list__) else 1
+        for i, item in enumerate(args0[0].x)
+    ]
+
+    ori_count = np.pad(
+        ori_count, pad_width=(0, rep_size - ori_size), constant_values=1
+    ).astype(int)
+    reps_int = (reps_int / ori_count).astype(int)
+
+    args_to_use = np.concatenate(([1], reps_int[::-1]))
+    if use_arg_1:
+        args[1]["reps"] = args_to_use
+    else:
+        args0[1] = args_to_use
+
+    csdm = get_new_csdm_object_after_applying_function(
+        function, *args0, **args[1], **kwargs
+    )
+
+    for _ in range(rep_size - ori_size):
+        if isinstance(reps[ori_size + _], __dimensions_list__):
+            csdm.x.append(reps[ori_size + _])
+        else:
+            csdm.x.append(LinearDimension(count=reps[rep_size + _], increment="1"))
+
+    for idx in range(ori_size):
+        dim = csdm.x[idx]
+        if isinstance(reps[idx], __dimensions_list__):
+            csdm.x[idx] = reps[idx]
+        else:
+            if dim.type == "linear":
+                dim.count *= int(reps[idx])
+            elif dim.type == "monotonic":
+                inc = dim.coordinates[1] - dim.coordinates[0]
+                right = inc * np.arange(int(reps[idx])) + dim.coordinates[1]
+                coords = np.concatenate((dim.coordinates, right))
+                dim.coordinates = coords
+            if dim.type == "labeled":
+                right = ["0"] * int(reps[idx])
+                coords = list(dim.labels) + right
+                dim.labels = coords
+    return csdm
