@@ -12,7 +12,7 @@ __all__ = ["Decoder"]
 class Decoder:
     """Decoder class"""
 
-    def __new__(self, encoding, quantity_type, components, dtype):
+    def __new__(cls, encoding, quantity_type, components, dtype):
         """Decode the components based on the encoding key value.
 
         The valid encodings are 'base64', 'none' (text), and 'raw' (binary).
@@ -20,7 +20,7 @@ class Decoder:
         if encoding != "raw":
             check_number_of_components_and_encoding_type(len(components), quantity_type)
         component_len = quantity_type.p
-        method = getattr(self, "decode_" + encoding)
+        method = getattr(cls, "decode_" + encoding)
         return method(components, dtype, component_len)
 
     @staticmethod
@@ -50,7 +50,10 @@ class Decoder:
     def decode_raw(components, dtype, component_len=None):
         """Read components form a binary buffer"""
         components = np.frombuffer(components, dtype=dtype)
-        components.shape = component_len, int(components.size / component_len)
+        if not components.flags["WRITEABLE"]:
+            components = components.copy()
+        size = int(components.size / component_len)
+        components = components.reshape(component_len, size)
         return components
 
 
