@@ -7,9 +7,9 @@ import numpy as np
 from csdmpy.dimension.labeled import LabeledDimension
 from csdmpy.dimension.linear import LinearDimension
 from csdmpy.dimension.monotonic import MonotonicDimension
-from csdmpy.units import string_to_quantity  # lgtm [py/import-own-module]
-from csdmpy.utils import _get_dictionary  # lgtm [py/import-own-module]
-from csdmpy.utils import validate  # lgtm [py/import-own-module]
+from csdmpy.units import string_to_quantity
+from csdmpy.utils import _get_dictionary
+from csdmpy.utils import validate
 
 __author__ = "Deepansh J. Srivastava"
 __email__ = "srivastava.89@osu.edu"
@@ -172,12 +172,16 @@ class Dimension:
     def __eq__(self, other):
         """Overrides the default implementation."""
         other = other.subtype if isinstance(other, Dimension) else other
-        return True if self.subtype == other else False
+        return self.subtype == other
 
     def __mul__(self, other):
-        """Multiply the Dimension object by a scalar."""
+        """Multiply the Dimension object by a right scalar."""
         return self.subtype.__mul__(other)
 
+    def __rmul__(self, other):
+        """Multiply the Dimension object by a left scalar."""
+        return self.subtype.__rmul__(other)
+
     def __imul__(self, other):
         """Multiply the Dimension object by a scalar, in-place."""
         return self.subtype.__imul__(other)
@@ -190,6 +194,31 @@ class Dimension:
         """Divide the Dimension object by a scalar, in-place."""
         return self.subtype.__itruediv__(other)
 
+    def __getitem__(self, indices):
+        """Return a dimension object corresponding to given indices."""
+        dim_ = self.subtype if hasattr(self, "subtype") else self
+
+        length_ = self.coordinates[indices].size
+        if length_ <= 1:
+            return self.coordinates[indices]
+
+        if hasattr(dim_, "_equivalencies"):
+            equivalencies_ = dim_._equivalencies
+            dim_._equivalencies = None
+            coordinates = self.coordinates[indices]
+            new_dim = as_dimension(coordinates.value, unit=str(coordinates.unit))
+            dim_._equivalencies = equivalencies_
+            new_dim._equivalencies = equivalencies_
+
+        else:
+            coordinates = self.coordinates[indices]
+            new_dim = as_dimension(coordinates)
+
+        new_dim.copy_metadata(dim_)
+        if hasattr(new_dim, "complex_fft"):
+            new_dim.complex_fft = False
+        return new_dim
+
     # ======================================================================= #
     #                          Dimension Attributes                           #
     # ======================================================================= #
@@ -532,6 +561,11 @@ class Dimension:
     def label(self, label=""):
         self.subtype.label = label
 
+    @property
+    def size(self):
+        """Return the dimension count"""
+        return self.count
+
     @property
     def count(self):
         r"""Number of coordinates, :math:`N_k \ge 1`, along the dimension.
@@ -675,7 +709,7 @@ class Dimension:
 
             >>> x2 = Dimension(type="labeled", labels=["Cu", "Ag", "Au"])
 
-        then the labels along the labeled dimension are
+        then the labels along the labeled dimensions are
 
         .. doctest::
 
@@ -689,7 +723,7 @@ class Dimension:
 
             .. doctest::
 
-                >>> np.all(x2.coordinates == x2.labels)
+                >>> bool(np.all(x2.coordinates == x2.labels))
                 True
 
         In the above example, ``x2`` is an instance of the :ref:`dim_api` class with
@@ -726,10 +760,9 @@ class Dimension:
     #                           Dimension Methods                             #
     # ======================================================================= #
 
-    def _copy_metadata(self, obj):
+    def copy_metadata(self, obj):
         """Copy Dimension metadata"""
-        self.subtype._type = obj.subtype._type
-        self.subtype._copy_metadata(obj)
+        self.subtype.copy_metadata(obj)
 
     def to_dict(self):
         """Alias to the `dict()` method of the class."""
@@ -756,7 +789,7 @@ class Dimension:
         """
         return self.subtype.is_quantitative()
 
-    def to(self, unit="", equivalencies=None):
+    def to(self, unit="", equivalencies=None, update_attrs=False):
         r"""Convert the coordinates along the dimension to the unit, `unit`.
 
         This method is a wrapper of the `to` method from the
@@ -772,13 +805,15 @@ class Dimension:
             [10.  10.5 11.  11.5 12.  12.5 13.  13.5 14.  14.5] mT
 
         Args:
-            `unit` : A string containing a unit with the same dimensionality as the
+            unit : A string containing a unit with the same dimensionality as the
                      coordinates along the dimension.
+            equivalencies: Convert to equivalent units
+            update_attrs: Update attribute units if equivalencies is None.
 
         Raises:
             AttributeError: For `labeled` dimensions.
         """
-        self.subtype.to(unit, equivalencies)
+        self.subtype.to(unit, equivalencies, update_attrs)
 
     def copy(self):
         """Return a copy of the Dimension object."""
