@@ -105,7 +105,7 @@ class LabeledDimension(BaseDimension):
     #                                 Methods                                 #
     # ----------------------------------------------------------------------- #
 
-    def _copy_metadata(self, obj):
+    def copy_metadata(self, obj):
         """Copy LabeledDimension metadata."""
         obj = obj.subtype if hasattr(obj, "subtype") else obj
         if isinstance(obj, LabeledDimension):
