@@ -1,8 +1,64 @@
 import numpy as np
+import scipy as sp
 
 import csdmpy as cp
-from csdmpy.utils import _check_dimension_indices  # lgtm [py/import-own-module]
-from csdmpy.utils import _get_broadcast_shape  # lgtm [py/import-own-module]
+from csdmpy.utils import _check_dimension_indices
+from csdmpy.utils import _get_broadcast_shape
+
+
+__ufunc_list_dimensionless_unit__ = [
+    np.sin,
+    np.cos,
+    np.tan,
+    np.arcsin,
+    np.arccos,
+    np.arctan,
+    np.sinh,
+    np.cosh,
+    np.tanh,
+    np.arcsinh,
+    np.arccosh,
+    np.arctanh,
+    np.exp,
+    np.exp2,
+    np.log,
+    np.log2,
+    np.log10,
+    np.expm1,
+    np.log1p,
+]
+
+__ufunc_list_unit_independent__ = [
+    np.negative,
+    np.positive,
+    np.absolute,
+    np.fabs,
+    np.rint,
+    np.sign,
+    np.conj,
+    np.conjugate,
+]
+
+__ufunc_list_applies_to_unit__ = [np.sqrt, np.square, np.cbrt, np.reciprocal, np.power]
+
+__function_reduction_list__ = [
+    np.max,
+    np.min,
+    np.sum,
+    np.mean,
+    np.var,
+    np.std,
+    np.prod,
+    np.cumsum,
+    np.cumprod,
+    np.argmin,
+    np.argmax,
+]
+
+__other_functions__ = [np.round, np.real, np.imag, np.clip, np.around, np.angle]
+
+__shape_manipulation_functions__ = [np.transpose]
+__array_manipulation__ = [np.flip]
 
 
 def fft(csdm, axis=0):
@@ -37,21 +93,33 @@ def fft(csdm, axis=0):
     ndim = len(csdm_new.dimensions)
 
     if dimension_object._complex_fft:
+        scale_factor = 1.0 if np.isfinite(dimension_object.reciprocal.period) else 2.0
         phase = np.exp(2j * np.pi * coordinates_offset_res * coordinates)
         phase_grid = _get_broadcast_shape(phase, ndim, axis=index)
         for item in csdm_new.dependent_variables:
+            comp_shape_len = len(item.subtype._components.shape)
+            slice_ = get_cross_section_slice(index, comp_shape_len)
+
             phased_signal = item.subtype._components * phase_grid
-            ft_shift = np.fft.ifftshift(phased_signal, axes=index)
-            signal_ft = np.fft.ifft(ft_shift, axis=index)
+            ft_shift = sp.fft.ifftshift(phased_signal, axes=index)
+            signal_ft = sp.fft.ifft(ft_shift, axis=index)
+            signal_ft[slice_] *= scale_factor
 
             item.subtype._components = signal_ft
         dimension_object._complex_fft = False
+
     else:  # FFT is false
+        scale_factor = 1.0 if np.isfinite(dimension_object.period) else 2.0
         phase = np.exp(-2j * np.pi * coordinates_offset * coordinates_res)
         phase_grid = _get_broadcast_shape(phase, ndim, axis=index)
         for item in csdm_new.dependent_variables:
-            ft = np.fft.fft(item.subtype._components, axis=index)
-            ft_shift = np.fft.fftshift(ft, axes=index)
+            comp_shape_len = len(item.subtype._components.shape)
+            slice_ = get_cross_section_slice(index, comp_shape_len)
+
+            item.subtype._components[slice_] /= scale_factor
+
+            ft = sp.fft.fft(item.subtype._components, axis=index)
+            ft_shift = sp.fft.fftshift(ft, axes=index)
             signal_ft = ft_shift * phase_grid
 
             item.subtype._components = signal_ft
@@ -64,6 +132,14 @@ def fft(csdm, axis=0):
     return csdm_new
 
 
+def get_cross_section_slice(index, size):
+    """Return a slice object for a size dimensional dataset at index `index`."""
+    slc = [
+        slice(None, 1, None) if i == -index - 1 else slice(None) for i in range(size)
+    ]
+    return tuple(slc[::-1])
+
+
 #
 # def _compare_cv_object(cv1, cv2):
 #     if cv1.gcv._getparams == cv2.gcv._getparams:
