@@ -27,8 +27,7 @@ def test_linear_new():
     # type
     assert data.dimensions[0].type == "linear"
 
-    error = "can't set attribute"
-    with pytest.raises(AttributeError, match=f".*{error}.*"):
+    with pytest.raises(AttributeError):
         data.dimensions[0].type = "monotonic"
 
     # increment
@@ -72,8 +71,10 @@ def test_linear_new():
 
     # count
     assert data.dimensions[0].count == 10
+    assert data.dimensions[0].size == 10
     data.dimensions[0].count = 12
     assert data.dimensions[0].count == 12
+    assert data.dimensions[0].size == 12
     assert np.all(data.dimensions[0].coordinates.value == np.arange(12) * 10.0 + 5.0)
     assert np.all(data.x[0].coords.value == np.arange(12) * 10.0 + 5.0)
     assert np.all(
@@ -236,7 +237,7 @@ def test_linearDimension():
     assert np.allclose(freq.coords.value, (np.arange(10) * 0.1 + 1))
 
     freq.to("ppm", "nmr_frequency_ratio")
-    values = (np.arange(10) * 100 + 1000) / (1 - (0.001 + 0.0005))
+    values = (np.arange(10) * 100 + 1000) / 1
     assert np.allclose(freq.coordinates.value, values)
     assert np.allclose(freq.coords.value, values)
 
@@ -265,6 +266,13 @@ def test_monotonic_new():
         description="Far far away.",
         coordinates=["1 m", "100 m", "1 km", "1 Gm", "0.25 lyr"],
     )
+    # mult
+    dim_x2 = dim_x * 4
+    assert np.allclose(dim_x2.coordinates, 4 * dim_x.coordinates)
+
+    dim_x2 = 4 * dim_x
+    assert np.allclose(dim_x2.coordinates, 4 * dim_x.coordinates)
+
     data = cp.CSDM(dimensions=[dim_x, dim_x.copy()])
 
     for dim in data.dimensions:
@@ -307,6 +315,7 @@ def test_monotonic_new():
 
         # count
         assert dim.count == 5
+        assert dim.size == 5
         error = "Cannot set the count,"
         with pytest.raises(ValueError, match=f".*{error}.*"):
             dim.count = 12
@@ -320,8 +329,7 @@ def test_monotonic_new():
         with pytest.raises(AttributeError, match=f".*{error}.*"):
             _ = dim.coordinates_offset
 
-        error = "can't set attribute"
-        with pytest.raises(AttributeError, match=f".*{error}.*"):
+        with pytest.raises(AttributeError):
             dim.coordinates_offset = "1"
 
         # origin offset
@@ -525,6 +533,7 @@ def test_labeled_new():
     data.dimensions.append(dim)
 
     assert data.dimensions[0].is_quantitative() is False
+    assert data.dimensions[0].size == 4
 
     # description
     assert data.dimensions[0].description == "Far far away."
@@ -623,6 +632,13 @@ def test_as_dimension():
     assert np.allclose(dim.coordinates.value, array)
     assert np.allclose(dim.coords.value, array)
 
+    # dim mult
+    dim2 = 4 * dim
+    assert dim2.increment == dim.increment * 4
+
+    dim2 = dim * 4
+    assert dim2.increment == dim.increment * 4
+
     # linear
     error = "Invalid array for Dimension object."
     with pytest.raises(ValueError, match=f".*{error}.*"):
@@ -688,4 +704,71 @@ def test_dimension_scale():
     dim2 = dim / 2.4
     assert np.allclose(dim2.coordinates.value, np.arange(10) / 2.4)
     assert dim2.quantity_name == "length"
-    assert type(dim2.quantity_name) == str
+    assert type(dim2.quantity_name) is str
+
+
+def test_dimension_equality_within_precision():
+    """Test dimension equality within precision"""
+    dim_1 = cp.as_dimension([1, 10], type="monotonic", unit="s")
+    dim_2 = cp.as_dimension([1 - 1e-8, 10 + 1e-12], type="monotonic", unit="s")
+
+    assert dim_2 == dim_1
+
+    dim_1 = cp.as_dimension([1, 10], type="monotonic", unit="s")
+    dim_2 = cp.as_dimension([1 - 1e-8, 10 + 1e-12], type="monotonic", unit="m")
+
+    assert dim_2 != dim_1
+
+
+def test_attribute_unit_update_linear():
+    """Test attribute units"""
+    d1 = cp.as_dimension(
+        np.arange(100) + 10, unit="Hz", origin_offset="135 MHz", period="235 Hz"
+    )
+
+    d2 = d1 * cp.ScalarQuantity("s")
+
+    Hz_s_unit = str(u.Unit("Hz s"))
+    MHz_s_unit = str(u.Unit("MHz s"))
+
+    assert str(d2.increment.unit) == Hz_s_unit
+    assert str(d2.coordinates_offset.unit) == Hz_s_unit
+    assert str(d2.origin_offset.unit) == MHz_s_unit
+    assert str(d2.period.unit) == Hz_s_unit
+
+    # convert to unitless without attribute unit updates
+    d2.to("")
+    assert str(d2.increment.unit) == Hz_s_unit
+    assert str(d2.coordinates_offset.unit) == Hz_s_unit
+    assert str(d2.origin_offset.unit) == MHz_s_unit
+    assert str(d2.period.unit) == Hz_s_unit
+
+    # convert to unitless with attribute unit update
+    unitless = str(u.Unit(""))
+    d2.to("", update_attrs=True)
+    assert str(d2.increment.unit) == unitless
+    assert str(d2.coordinates_offset.unit) == unitless
+    assert str(d2.origin_offset.unit) == unitless
+    assert str(d2.period.unit) == unitless
+
+
+def test_attribute_unit_update_monotonic():
+    """Test attribute units"""
+    d1 = cp.as_dimension([1, 3, 6, 10, 20, 100], unit="A", origin_offset="1.1 A")
+
+    d2 = d1 * cp.ScalarQuantity("ohm")
+
+    unit1 = str(u.Unit("A ohm"))
+
+    assert str(d2.coordinates.unit) == unit1
+    assert str(d2.origin_offset.unit) == unit1
+
+    # convert to unitless without attribute unit updates
+    d2.to("V")
+    assert str(d2.origin_offset.unit) == unit1
+
+    # convert to unitless with attribute unit update
+    unit2 = str(u.Unit("V"))
+    d2.to("V", update_attrs=True)
+    assert str(d2.coordinates.unit) == unit2
+    assert str(d2.origin_offset.unit) == unit2
